# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-05-14 18:41
from __future__ import unicode_literals

from django.db import migrations, models
import localflavor.us.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Address',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('address_1', models.CharField(max_length=128, verbose_name='address')),
                ('address_2', models.CharField(blank=True, max_length=128, verbose_name="address cont'd")),
                ('city', models.CharField(max_length=64, verbose_name='city')),
                ('state', localflavor.us.models.USStateField(default='NY', verbose_name='state')),
                ('zip_code', models.CharField(max_length=10)),
                ('phone_number', localflavor.us.models.PhoneNumberField()),
                ('customer_name', models.CharField(help_text="Customer's last name", max_length=128)),
            ],
        ),
    ]
